/*
 * Copyright (c) 2011, Kai Schwebke. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Kai Schwebke (kai@schwebke.com)
 * or visit www.schwebke.com if you need additional information or have any
 * questions.
 */

/*
 * $Id: ImageWindow.java 595 2011-12-27 06:46:29Z kai $
 */

package com.schwebke;

import java.awt.Rectangle;
import java.io.File;
import java.io.IOException;

/**
 *
 * @author kai
 */
public class ImageWindow extends javax.swing.JDialog {

    /** Creates new form ImageWindow */
    public ImageWindow(javax.swing.JFrame parent, String title, File imgFile) throws IOException {
        super(parent, title);
        this.imgFile = imgFile;
        imagePanel = new ImagePanel(imgFile);
        initComponents();
        Rectangle pB = parent.getBounds();
        Rectangle b = getBounds();
        setBounds(pB.x+100, pB.y+50, b.width, b.height);
    }

    /** This method is called from within the constructor to
     * initialize the form.
     * WARNING: Do NOT modify this code. The content of this method is
     * always regenerated by the Form Editor.
     */
    @SuppressWarnings("unchecked")
    // <editor-fold defaultstate="collapsed" desc="Generated Code">//GEN-BEGIN:initComponents
    private void initComponents() {

        jToolBar1 = new javax.swing.JToolBar();
        jExitButton = new javax.swing.JButton();
        jSeparator1 = new javax.swing.JToolBar.Separator();
        jZoomInButton = new javax.swing.JButton();
        jZoomOutButton = new javax.swing.JButton();
        jPanel1 = new javax.swing.JPanel();
        jImageScrollPane = new javax.swing.JScrollPane();

        setDefaultCloseOperation(javax.swing.WindowConstants.DISPOSE_ON_CLOSE);

        jToolBar1.setRollover(true);

        jExitButton.setIcon(new javax.swing.ImageIcon(getClass().getResource("/com/schwebke/jregexanalyser/res/IconExit.png"))); // NOI18N
        jExitButton.setToolTipText("close window");
        jExitButton.setFocusable(false);
        jExitButton.setHorizontalTextPosition(javax.swing.SwingConstants.CENTER);
        jExitButton.setVerticalTextPosition(javax.swing.SwingConstants.BOTTOM);
        jExitButton.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                jExitButtonActionPerformed(evt);
            }
        });
        jToolBar1.add(jExitButton);
        jToolBar1.add(jSeparator1);

        jZoomInButton.setIcon(new javax.swing.ImageIcon(getClass().getResource("/com/schwebke/ZoomInIcon.png"))); // NOI18N
        jZoomInButton.setToolTipText("zoom in");
        jZoomInButton.setFocusable(false);
        jZoomInButton.setHorizontalTextPosition(javax.swing.SwingConstants.CENTER);
        jZoomInButton.setVerticalTextPosition(javax.swing.SwingConstants.BOTTOM);
        jZoomInButton.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                jZoomInButtonActionPerformed(evt);
            }
        });
        jToolBar1.add(jZoomInButton);

        jZoomOutButton.setIcon(new javax.swing.ImageIcon(getClass().getResource("/com/schwebke/ZoomOutIcon.png"))); // NOI18N
        jZoomOutButton.setToolTipText("zoom out");
        jZoomOutButton.setFocusable(false);
        jZoomOutButton.setHorizontalTextPosition(javax.swing.SwingConstants.CENTER);
        jZoomOutButton.setVerticalTextPosition(javax.swing.SwingConstants.BOTTOM);
        jZoomOutButton.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                jZoomOutButtonActionPerformed(evt);
            }
        });
        jToolBar1.add(jZoomOutButton);

        getContentPane().add(jToolBar1, java.awt.BorderLayout.PAGE_START);

        jPanel1.setPreferredSize(new java.awt.Dimension(360, 560));

        jImageScrollPane.setViewportView(imagePanel);

        javax.swing.GroupLayout jPanel1Layout = new javax.swing.GroupLayout(jPanel1);
        jPanel1.setLayout(jPanel1Layout);
        jPanel1Layout.setHorizontalGroup(
            jPanel1Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addComponent(jImageScrollPane, javax.swing.GroupLayout.DEFAULT_SIZE, 448, Short.MAX_VALUE)
        );
        jPanel1Layout.setVerticalGroup(
            jPanel1Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addComponent(jImageScrollPane, javax.swing.GroupLayout.DEFAULT_SIZE, 591, Short.MAX_VALUE)
        );

        getContentPane().add(jPanel1, java.awt.BorderLayout.CENTER);

        pack();
    }// </editor-fold>//GEN-END:initComponents

    private void jExitButtonActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_jExitButtonActionPerformed
        setVisible(false);
        dispose();
    }//GEN-LAST:event_jExitButtonActionPerformed

    private void jZoomInButtonActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_jZoomInButtonActionPerformed
        imagePanel.zoomIn();
    }//GEN-LAST:event_jZoomInButtonActionPerformed

    private void jZoomOutButtonActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_jZoomOutButtonActionPerformed
        imagePanel.zoomOut();
    }//GEN-LAST:event_jZoomOutButtonActionPerformed

    // Variables declaration - do not modify//GEN-BEGIN:variables
    private javax.swing.JButton jExitButton;
    private javax.swing.JScrollPane jImageScrollPane;
    private javax.swing.JPanel jPanel1;
    private javax.swing.JToolBar.Separator jSeparator1;
    private javax.swing.JToolBar jToolBar1;
    private javax.swing.JButton jZoomInButton;
    private javax.swing.JButton jZoomOutButton;
    // End of variables declaration//GEN-END:variables
    private File imgFile;
    private ImagePanel imagePanel;
}
